braindecode package
===================

.. automodule:: braindecode
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::

   braindecode.datasets
   braindecode.datautil
   braindecode.experiments
   braindecode.models
   braindecode.visualization

Submodules
----------

braindecode.callbacks module
----------------------------

.. automodule:: braindecode.callbacks
   :members:
   :undoc-members:
   :show-inheritance:

braindecode.classifier module
-----------------------------

.. automodule:: braindecode.classifier
   :members:
   :undoc-members:
   :show-inheritance:

braindecode.losses module
-------------------------

.. automodule:: braindecode.losses
   :members:
   :undoc-members:
   :show-inheritance:

braindecode.monitors module
---------------------------

.. automodule:: braindecode.monitors
   :members:
   :undoc-members:
   :show-inheritance:

braindecode.scoring module
--------------------------

.. automodule:: braindecode.scoring
   :members:
   :undoc-members:
   :show-inheritance:

braindecode.util module
-----------------------

.. automodule:: braindecode.util
   :members:
   :undoc-members:
   :show-inheritance:

braindecode.version module
--------------------------

.. automodule:: braindecode.version
   :members:
   :undoc-members:
   :show-inheritance:

